@@ -75,20 +75,16 @@ namespace DigikamAdjustLevelsImagesPlugin
 {
 
 AdjustLevelDialog::AdjustLevelDialog(QWidget* parent, uint *imageData, uint width, uint height)
-                 : KDialogBase(Plain, i18n("Adjust Color Levels"), Help|User1|Ok|Cancel, Ok,
-                               parent, 0, true, true, i18n("&Reset Values"))
+                 : ImageTabDialog(parent, i18n("Adjust Color Levels"), "adjustlevels", 
+                                  true, true, false)
 {
-    parentWidget()->setCursor( KCursor::waitCursor() );
-    
     // Create an empty instance of levels to use.
     m_levels = new Digikam::ImageLevels();
 
-    setButtonWhatsThis ( User1, i18n("<p>Reset levels values from the current selected channel.") );
-
     // About data and help button.
 
     KAboutData* about = new KAboutData("digikamimageplugins",
-                                       I18N_NOOP("Adjust Levels"),
+                                       I18N_NOOP("Adjust Color Levels"),
                                        digikamimageplugins_version,
                                        I18N_NOOP("An image-histogram-levels adjustment plugin for digiKam."),
                                        KAboutData::License_GPL,
@@ -99,49 +95,16 @@ AdjustLevelDialog::AdjustLevelDialog(QWidget* parent, uint *imageData, uint widt
     about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
                      "caulier dot gilles at free.fr");
 
-    m_helpButton = actionButton( Help );
-    KHelpMenu* helpMenu = new KHelpMenu(this, about, false);
-    helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Adjust Levels Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
-    m_helpButton->setPopup( helpMenu->menu() );
-
+    setAboutData(about);
+    
     // -------------------------------------------------------------
 
-    QGridLayout* topLayout = new QGridLayout( plainPage(), 3, 2 , marginHint(), spacingHint());
+    QWidget *gboxSettings = new QWidget(plainPage());
+    QGridLayout* grid = new QGridLayout( gboxSettings, 9, 5, marginHint(), spacingHint());
 
-    QFrame *headerFrame = new QFrame( plainPage() );
-    headerFrame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QHBoxLayout* layout = new QHBoxLayout( headerFrame );
-    layout->setMargin( 2 ); // to make sure the frame gets displayed
-    layout->setSpacing( 0 );
-    QLabel *pixmapLabelLeft = new QLabel( headerFrame, "pixmapLabelLeft" );
-    pixmapLabelLeft->setScaledContents( false );
-    layout->addWidget( pixmapLabelLeft );
-    QLabel *labelTitle = new QLabel( i18n("Adjust Color Levels"), headerFrame, "labelTitle" );
-    layout->addWidget( labelTitle );
-    layout->setStretchFactor( labelTitle, 1 );
-    topLayout->addMultiCellWidget(headerFrame, 0, 0, 0, 1);
-
-    QString directory;
-    KGlobal::dirs()->addResourceType("digikamimageplugins_banner_left", KGlobal::dirs()->kde_default("data") +
-                                                                        "digikamimageplugins/data");
-    directory = KGlobal::dirs()->findResourceDir("digikamimageplugins_banner_left",
-                                                 "digikamimageplugins_banner_left.png");
-
-    pixmapLabelLeft->setPaletteBackgroundColor( QColor(201, 208, 255) );
-    pixmapLabelLeft->setPixmap( QPixmap( directory + "digikamimageplugins_banner_left.png" ) );
-    labelTitle->setPaletteBackgroundColor( QColor(201, 208, 255) );
-
-    // -------------------------------------------------------------
-
-    QGroupBox *gbox = new QGroupBox(plainPage());
-    gbox->setFlat(false);
-    gbox->setTitle(i18n("Settings"));
-    QGridLayout* grid = new QGridLayout( gbox, 6, 5, 20, spacingHint());
-
-    QLabel *label1 = new QLabel(i18n("Channel:"), gbox);
+    QLabel *label1 = new QLabel(i18n("Channel:"), gboxSettings);
     label1->setAlignment ( Qt::AlignRight | Qt::AlignVCenter );
-    m_channelCB = new QComboBox( false, gbox );
+    m_channelCB = new QComboBox( false, gboxSettings );
     m_channelCB->insertItem( i18n("Luminosity") );
     m_channelCB->insertItem( i18n("Red") );
     m_channelCB->insertItem( i18n("Green") );
@@ -157,32 +120,52 @@ AdjustLevelDialog::AdjustLevelDialog(QWidget* parent, uint *imageData, uint widt
                                        "This channel corresponds to the transparency value and "
                                        "is supported by some image formats, such as PNG or GIF."));
 
-    QLabel *label2 = new QLabel(i18n("Scale:"), gbox);
-    label2->setAlignment ( Qt::AlignRight | Qt::AlignVCenter);
-    m_scaleCB = new QComboBox( false, gbox );
-    m_scaleCB->insertItem( i18n("Linear") );
-    m_scaleCB->insertItem( i18n("Logarithmic") );
-    m_scaleCB->setCurrentText( i18n("Logarithmic") );
-    QWhatsThis::add( m_scaleCB, i18n("<p>Select here the histogram scale.<p>"
+    m_scaleBG = new QHButtonGroup(gboxSettings);
+    m_scaleBG->setExclusive(true);
+    m_scaleBG->setFrameShape(QFrame::NoFrame);
+    m_scaleBG->setInsideMargin( 0 );
+    QWhatsThis::add( m_scaleBG, i18n("<p>Select here the histogram scale.<p>"
                                      "If the image's maximal counts are small, you can use the linear scale.<p>"
                                      "Logarithmic scale can be used when the maximal counts are big; "
                                      "if it is used, all values (small and large) will be visible on the graph."));
+    
+    QPushButton *linHistoButton = new QPushButton( m_scaleBG );
+    QToolTip::add( linHistoButton, i18n( "<p>Linear" ) );
+    m_scaleBG->insert(linHistoButton, Digikam::HistogramWidget::LinScaleHistogram);
+    KGlobal::dirs()->addResourceType("histogram-lin", KGlobal::dirs()->kde_default("data") + "digikam/data");
+    QString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
+    linHistoButton->setPixmap( QPixmap( directory + "histogram-lin.png" ) );
+    linHistoButton->setToggleButton(true);
+    
+    QPushButton *logHistoButton = new QPushButton( m_scaleBG );
+    QToolTip::add( logHistoButton, i18n( "<p>Logarithmic" ) );
+    m_scaleBG->insert(logHistoButton, Digikam::HistogramWidget::LogScaleHistogram);
+    KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
+    logHistoButton->setPixmap( QPixmap( directory + "histogram-log.png" ) );
+    logHistoButton->setToggleButton(true);       
 
-    grid->addMultiCellWidget(label1, 0, 0, 0, 0);
-    grid->addMultiCellWidget(m_channelCB, 0, 0, 1, 1);
-    grid->addMultiCellWidget(label2, 0, 0, 3, 3);
-    grid->addMultiCellWidget(m_scaleCB, 0, 0, 4, 4);
+    QHBoxLayout* l1 = new QHBoxLayout();
+    l1->addWidget(label1);
+    l1->addWidget(m_channelCB);
+    l1->addWidget(m_scaleBG);
+    l1->addStretch(10);
+    
+    grid->addMultiCellLayout(l1, 0, 0, 0, 3);
 
-    QFrame *frame = new QFrame(gbox);
-    frame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QVBoxLayout* l = new QVBoxLayout(frame, 5, 0);
+    // -------------------------------------------------------------
 
+    QFrame *frame = new QFrame(gboxSettings);
+    frame->setFrameStyle(QFrame::NoFrame);
+    QVBoxLayout* l2 = new QVBoxLayout(frame, 2, 0);
     m_histogramWidget = new Digikam::HistogramWidget(256, 140, imageData, width, height, frame, false);
     QWhatsThis::add( m_histogramWidget, i18n("<p>This is the histogram drawing of the selected image channel"));
-    l->addWidget(m_histogramWidget, 0);
+    l2->addWidget(m_histogramWidget, 0);
     grid->addMultiCellWidget(frame, 1, 1, 0, 4);
 
-    m_hGradientMinInput = new KGradientSelector( KSelector::Horizontal, gbox );
+    // -------------------------------------------------------------
+    
+    m_hGradientMinInput = new KGradientSelector( KSelector::Horizontal, gboxSettings );
     m_hGradientMinInput->setFixedHeight( 20 );
     m_hGradientMinInput->setMinValue(0);
     m_hGradientMinInput->setMaxValue(255);
@@ -191,7 +174,7 @@ AdjustLevelDialog::AdjustLevelDialog(QWidget* parent, uint *imageData, uint widt
     m_hGradientMinInput->setColors( QColor( "black" ), QColor( "white" ) );
     grid->addMultiCellWidget(m_hGradientMinInput, 2, 2, 0, 4);
 
-    m_hGradientMaxInput = new KGradientSelector( KSelector::Horizontal, gbox );
+    m_hGradientMaxInput = new KGradientSelector( KSelector::Horizontal, gboxSettings );
     m_hGradientMaxInput->setFixedHeight( 20 );
     m_hGradientMaxInput->setMinValue(0);
     m_hGradientMaxInput->setMaxValue(255);
@@ -200,17 +183,17 @@ AdjustLevelDialog::AdjustLevelDialog(QWidget* parent, uint *imageData, uint widt
     m_hGradientMaxInput->setColors( QColor( "black" ), QColor( "white" ) );
     grid->addMultiCellWidget(m_hGradientMaxInput, 3, 3, 0, 4);
 
-    m_minInput = new QSpinBox(0, 255, 1, gbox);
+    m_minInput = new QSpinBox(0, 255, 1, gboxSettings);
     m_minInput->setValue(0);
     QWhatsThis::add( m_minInput, i18n("<p>Select here the minimal intensity input value of the histogram."));
     QToolTip::add( m_minInput, i18n( "Minimal intensity input." ) );
-    m_gammaInput = new KDoubleNumInput(gbox);
+    m_gammaInput = new KDoubleNumInput(gboxSettings);
     m_gammaInput->setPrecision(2);
     m_gammaInput->setRange(0.1, 10.0, 0.1);
     m_gammaInput->setValue(1.0);
     QToolTip::add( m_gammaInput, i18n( "Gamma input value." ) );
     QWhatsThis::add( m_gammaInput, i18n("<p>Select here the gamma input value."));
-    m_maxInput = new QSpinBox(0, 255, 1, gbox);
+    m_maxInput = new QSpinBox(0, 255, 1, gboxSettings);
     m_maxInput->setValue(255);
     QToolTip::add( m_maxInput, i18n( "Maximal intensity input." ) );
     QWhatsThis::add( m_maxInput, i18n("<p>Select here the maximal intensity input value of the histogram."));
@@ -218,7 +201,7 @@ AdjustLevelDialog::AdjustLevelDialog(QWidget* parent, uint *imageData, uint widt
     grid->addMultiCellWidget(m_maxInput, 3, 3, 5, 5);
     grid->addMultiCellWidget(m_gammaInput, 4, 4, 0, 5);
 
-    m_hGradientMinOutput = new KGradientSelector( KSelector::Horizontal, gbox );
+    m_hGradientMinOutput = new KGradientSelector( KSelector::Horizontal, gboxSettings );
     m_hGradientMinOutput->setColors( QColor( "black" ), QColor( "white" ) );
     QWhatsThis::add( m_hGradientMinOutput, i18n("<p>Select here the minimal intensity output value of the histogram."));    
     QToolTip::add( m_hGradientMinOutput, i18n( "Minimal intensity output." ) );
@@ -227,7 +210,7 @@ AdjustLevelDialog::AdjustLevelDialog(QWidget* parent, uint *imageData, uint widt
     m_hGradientMinOutput->setMaxValue(255);
     grid->addMultiCellWidget(m_hGradientMinOutput, 5, 5, 0, 4);
 
-    m_hGradientMaxOutput = new KGradientSelector( KSelector::Horizontal, gbox );
+    m_hGradientMaxOutput = new KGradientSelector( KSelector::Horizontal, gboxSettings );
     m_hGradientMaxOutput->setColors( QColor( "black" ), QColor( "white" ) );
     QWhatsThis::add( m_hGradientMaxOutput, i18n("<p>Select here the maximal intensity output value of the histogram."));
     QToolTip::add( m_hGradientMaxOutput, i18n( "Maximal intensity output." ) );
@@ -236,32 +219,20 @@ AdjustLevelDialog::AdjustLevelDialog(QWidget* parent, uint *imageData, uint widt
     m_hGradientMaxOutput->setMaxValue(255);
     grid->addMultiCellWidget(m_hGradientMaxOutput, 6, 6, 0, 4);
 
-    m_minOutput = new QSpinBox(0, 255, 1, gbox);
+    m_minOutput = new QSpinBox(0, 255, 1, gboxSettings);
     m_minOutput->setValue(0);
     QToolTip::add( m_minOutput, i18n( "Minimal intensity output." ) );
     QWhatsThis::add( m_minOutput, i18n("<p>Select here the minimal intensity output value of the histogram."));
-    m_maxOutput = new QSpinBox(0, 255, 1, gbox);
+    m_maxOutput = new QSpinBox(0, 255, 1, gboxSettings);
     m_maxOutput->setValue(255);
     QToolTip::add( m_maxOutput, i18n( "Maximal intensity output." ) );
     QWhatsThis::add( m_maxOutput, i18n("<p>Select here the maximal intensity output value of the histogram."));
     grid->addMultiCellWidget(m_minOutput, 5, 5, 5, 5);
     grid->addMultiCellWidget(m_maxOutput, 6, 6, 5, 5);
 
-    topLayout->addMultiCellWidget(gbox, 1, 1, 0, 0);
-
     // -------------------------------------------------------------
 
-    QHGroupBox *gbox3 = new QHGroupBox(i18n("All Channels' Levels"), plainPage());
-    m_loadButton = new QPushButton(i18n("&Load..."), gbox3);
-    QWhatsThis::add( m_loadButton, i18n("<p>Load levels settings from a Gimp levels text file."));
-    m_saveButton = new QPushButton(i18n("&Save As..."), gbox3);
-    QWhatsThis::add( m_saveButton, i18n("<p>Save levels settings to a Gimp levels text file."));
-    m_autoButton = new QPushButton(i18n("&Auto"), gbox3);
-    QWhatsThis::add( m_autoButton, i18n("<p>Adjust levels automatically."));
-    m_resetButton = new QPushButton(i18n("&Reset All"), gbox3);
-    QWhatsThis::add( m_resetButton, i18n("<p>Reset all channels' level values."));
-
-    m_pickerColorButtonGroup = new QHButtonGroup(gbox3);
+    m_pickerColorButtonGroup = new QHButtonGroup(gboxSettings);
     m_pickBlack = new QPushButton(m_pickerColorButtonGroup);
     m_pickerColorButtonGroup->insert(m_pickBlack, BlackTonal);
     KGlobal::dirs()->addResourceType("color-picker-black", KGlobal::dirs()->kde_default("data") +
@@ -269,7 +240,7 @@ AdjustLevelDialog::AdjustLevelDialog(QWidget* parent, uint *imageData, uint widt
     directory = KGlobal::dirs()->findResourceDir("color-picker-black", "color-picker-black.png");
     m_pickBlack->setPixmap( QPixmap( directory + "color-picker-black.png" ) );
     m_pickBlack->setToggleButton(true);
-    QToolTip::add( m_pickBlack, i18n( "All Channels shadow tone color picker" ) );
+    QToolTip::add( m_pickBlack, i18n( "All channels shadow tone color picker" ) );
     QWhatsThis::add( m_pickBlack, i18n("<p>With this button, you can pick the color from original image used to set <b>Shadow Tone</b> "
                                        "levels input on Red, Green, Blue, and Luminosity channels."));
     m_pickGray  = new QPushButton(m_pickerColorButtonGroup);
@@ -279,7 +250,7 @@ AdjustLevelDialog::AdjustLevelDialog(QWidget* parent, uint *imageData, uint widt
     directory = KGlobal::dirs()->findResourceDir("color-picker-gray", "color-picker-gray.png");
     m_pickGray->setPixmap( QPixmap( directory + "color-picker-gray.png" ) );
     m_pickGray->setToggleButton(true);
-    QToolTip::add( m_pickGray, i18n( "All Channels middle tone color picker" ) );
+    QToolTip::add( m_pickGray, i18n( "All channels middle tone color picker" ) );
     QWhatsThis::add( m_pickGray, i18n("<p>With this button, you can pick the color from original image used to set <b>Middle Tone</b> "
                                       "levels input on Red, Green, Blue, and Luminosity channels."));
     m_pickWhite = new QPushButton(m_pickerColorButtonGroup);
@@ -289,46 +260,52 @@ AdjustLevelDialog::AdjustLevelDialog(QWidget* parent, uint *imageData, uint widt
     directory = KGlobal::dirs()->findResourceDir("color-picker-white", "color-picker-white.png");
     m_pickWhite->setPixmap( QPixmap( directory + "color-picker-white.png" ) );
     m_pickWhite->setToggleButton(true);
-    QToolTip::add( m_pickWhite, i18n( "All Channels highlight tone color picker" ) );
+    QToolTip::add( m_pickWhite, i18n( "All channels highlight tone color picker" ) );
     QWhatsThis::add( m_pickWhite, i18n("<p>With this button, you can pick the color from original image used to set <b>Highlight Tone</b> "
                                        "levels input on Red, Green, Blue, and Luminosity channels."));
     m_pickerColorButtonGroup->setExclusive(true);
     m_pickerColorButtonGroup->setFrameShape(QFrame::NoFrame);    
     
-    topLayout->addMultiCellWidget(gbox3, 3, 3, 0, 0);
+    m_autoButton = new QPushButton(i18n("&Auto"), gboxSettings);
+    QWhatsThis::add( m_autoButton, i18n("<p>Adjust all levels automatically."));
+    m_resetButton = new QPushButton(i18n("&Reset"), gboxSettings);
+    QWhatsThis::add( m_resetButton, i18n("<p>Reset levels values from the current selected channel."));
+    
+    QHBoxLayout* l3 = new QHBoxLayout();
+    l3->addWidget(m_pickerColorButtonGroup);
+    l3->addWidget(m_autoButton);
+    l3->addWidget(m_resetButton);
+    l3->addStretch(10);
+    
+    grid->addMultiCellLayout(l3, 7, 7, 0, 4);
 
     // -------------------------------------------------------------
-
-    QVGroupBox *gbox4 = new QVGroupBox(i18n("Preview"), plainPage());
-
-    QFrame *frame2 = new QFrame(gbox4);
-    frame2->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QVBoxLayout* l2  = new QVBoxLayout(frame2, 5, 0);
-    m_previewOriginalWidget = new Digikam::ImageGuideWidget(300, 200, frame2, true, 
-                                                            Digikam::ImageGuideWidget::PickColorMode);
-    QWhatsThis::add( m_previewOriginalWidget, i18n("<p>You can see here the original image. You can pick a color on the image using the color "
-                                                   "picker tools to select shadow, middle, and highlight tones to adjust the level points in the Red, "
-                                                   "Green, Blue, and Luminosity Channels."));
-    l2->addWidget(m_previewOriginalWidget, 0, Qt::AlignCenter);
-
-    QFrame *frame3 = new QFrame(gbox4);
-    frame3->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QVBoxLayout* l3  = new QVBoxLayout(frame3, 5, 0);
-    m_previewTargetWidget = new Digikam::ImageWidget(300, 200, frame3);
-    QWhatsThis::add( m_previewTargetWidget, i18n("<p>You can see here the image's level-adjustments preview."));
-    l3->addWidget(m_previewTargetWidget, 0, Qt::AlignCenter);
     
-    m_overExposureIndicatorBox = new QCheckBox(i18n("Over exposure indicator"), gbox4);
-    QWhatsThis::add( m_overExposureIndicatorBox, i18n("<p>If you enable this option, over-exposed pixels from the target image preview "
-                                                      "will be over-colored. This will not have an effect on the final rendering."));
-                                                      
-    topLayout->addMultiCellWidget(gbox4, 1, 3, 1, 1);
+    m_overExposureIndicatorBox = new QCheckBox(i18n("Over exposure indicator"), gboxSettings);
+    QWhatsThis::add( m_overExposureIndicatorBox, i18n("<p>If you enable this option, over-exposed pixels "
+                                                      "from the target image preview will be over-colored. "
+                                                      "This will not have an effect on the final rendering."));
+    grid->addMultiCellWidget(m_overExposureIndicatorBox, 8, 8, 0, 5);
+    grid->setRowStretch(9, 10);
+    
+    setUserAreaWidget(gboxSettings);    
+    
+    // -------------------------------------------------------------
 
-    adjustSize();
-    disableResize();
-
-    QTimer::singleShot(0, this, SLOT(slotResetAllChannels())); // Reset all parameters to the default values.
-    parentWidget()->setCursor( KCursor::arrowCursor()  );
+    m_previewOriginalWidget = previewOriginalWidget();
+    QWhatsThis::add( m_previewOriginalWidget, i18n("<p>Here you can see the original image. You can pick "
+                                                   "a color from the image using the color "
+                                                   "picker tools to select shadow, middle, and highlight "
+                                                   "tones to adjust the curves' points in the Red, "
+                                                   "Green, Blue, and Luminosity Channels."));
+    m_previewTargetWidget   = previewTargetWidget();
+    QWhatsThis::add( m_previewTargetWidget, i18n("<p>Here you can see the image's "
+                                                 "level-adjustments preview."));
+    
+    // -------------------------------------------------------------
+    
+    // Reset all parameters to the default values.
+    QTimer::singleShot(0, this, SLOT(slotDefault()));
                     
     // -------------------------------------------------------------
     // Channels and scale selection slots.
@@ -336,7 +313,7 @@ AdjustLevelDialog::AdjustLevelDialog(QWidget* parent, uint *imageData, uint widt
     connect(m_channelCB, SIGNAL(activated(int)),
             this, SLOT(slotChannelChanged(int)));
 
-    connect(m_scaleCB, SIGNAL(activated(int)),
+    connect(m_scaleBG, SIGNAL(released(int)),
             this, SLOT(slotScaleChanged(int)));
             
     connect(m_previewOriginalWidget, SIGNAL(spotPositionChanged(  const QColor &, bool, const QPoint & )),
@@ -344,6 +321,13 @@ AdjustLevelDialog::AdjustLevelDialog(QWidget* parent, uint *imageData, uint widt
 
     connect(m_overExposureIndicatorBox, SIGNAL(toggled (bool)),
             this, SLOT(slotEffect()));      
+            
+    connect(m_previewOriginalWidget, SIGNAL(signalResized()),
+            this, SLOT(slotEffect()));
+
+    connect(m_previewTargetWidget, SIGNAL(signalResized()),
+            this, SLOT(slotEffect()));                                                            
+                        
                         
     // -------------------------------------------------------------
     // Color sliders and spinbox slots.
@@ -382,29 +366,13 @@ AdjustLevelDialog::AdjustLevelDialog(QWidget* parent, uint *imageData, uint widt
             this, SLOT(slotAutoLevels()));
 
     connect(m_resetButton, SIGNAL(clicked()),
-            this, SLOT(slotResetAllChannels()));
-
-    connect(m_loadButton, SIGNAL(clicked()),
-            this, SLOT(slotLoadLevels()));
-
-    connect(m_saveButton, SIGNAL(clicked()),
-            this, SLOT(slotSaveLevels()));
+            this, SLOT(slotResetCurrentChannel()));
 }
 
 AdjustLevelDialog::~AdjustLevelDialog()
-{
-}
-
-void AdjustLevelDialog::slotHelp()
-{
-    KApplication::kApplication()->invokeHelp("adjustlevels", "digikamimageplugins");
-}
-
-void AdjustLevelDialog::closeEvent(QCloseEvent *e)
 {
     delete m_histogramWidget;
     delete m_levels;
-    e->accept();
 }
 
 void AdjustLevelDialog::slotSpotColorChanged(const QColor &color, bool release)
@@ -516,19 +484,7 @@ void AdjustLevelDialog::adjustSliders(int minIn, double gamIn, int maxIn, int mi
     m_hGradientMaxOutput->setValue(255 - maxOut);
 }
 
-void AdjustLevelDialog::slotResetAllChannels()
-{
-    for (int channel = 0 ; channel < 5 ; ++channel)
-       m_levels->levelsChannelReset(channel);
-
-    // Refresh the current levels config.
-    slotChannelChanged(m_channelCB->currentItem());
-    m_histogramWidget->reset();
-    
-    slotEffect();
-}
-
-void AdjustLevelDialog::slotUser1()
+void AdjustLevelDialog::slotResetCurrentChannel()
 {
     m_levels->levelsChannelReset(m_channelCB->currentItem());
 
@@ -552,13 +508,11 @@ void AdjustLevelDialog::slotAutoLevels()
 
 void AdjustLevelDialog::slotEffect()
 {
-    Digikam::ImageIface* ifaceOrg = m_previewOriginalWidget->imageIface();
-
     Digikam::ImageIface* ifaceDest = m_previewTargetWidget->imageIface();
 
-    uint* orgData = ifaceOrg->getPreviewData();
-    int   w       = ifaceOrg->previewWidth();
-    int   h       = ifaceOrg->previewHeight();
+    uint* orgData = ifaceDest->getPreviewData();
+    int   w       = ifaceDest->previewWidth();
+    int   h       = ifaceDest->previewHeight();
 
     // Create the new empty destination image data space.
     uint* desData = new uint[w*h];
@@ -570,7 +524,7 @@ void AdjustLevelDialog::slotEffect()
     m_levels->levelsLutProcess(orgData, desData, w, h);
 
     ifaceDest->putPreviewData(desData);
-    m_previewTargetWidget->update();
+    m_previewTargetWidget->updatePreview();
 
     delete [] orgData;
     delete [] desData;
@@ -578,13 +532,12 @@ void AdjustLevelDialog::slotEffect()
 
 void AdjustLevelDialog::slotOk()
 {
-    Digikam::ImageIface* ifaceOrg = m_previewOriginalWidget->imageIface();
+    kapp->setOverrideCursor( KCursor::waitCursor() );
+    Digikam::ImageIface ifaceDest(0, 0);
 
-    Digikam::ImageIface* ifaceDest = m_previewTargetWidget->imageIface();
-
-    uint* orgData = ifaceOrg->getOriginalData();
-    int   w       = ifaceOrg->originalWidth();
-    int   h       = ifaceOrg->originalHeight();
+    uint* orgData = ifaceDest.getOriginalData();
+    int   w       = ifaceDest.originalWidth();
+    int   h       = ifaceDest.originalHeight();
 
     // Create the new empty destination image data space.
     uint* desData = new uint[w*h];
@@ -595,7 +548,8 @@ void AdjustLevelDialog::slotOk()
     // Apply the lut to the image.
     m_levels->levelsLutProcess(orgData, desData, w, h);
 
-    ifaceDest->putOriginalData(i18n("Adjust Level"), desData);
+    ifaceDest.putOriginalData(i18n("Adjust Level"), desData);
+    kapp->restoreOverrideCursor();
 
     delete [] orgData;
     delete [] desData;
@@ -658,21 +612,25 @@ void AdjustLevelDialog::slotChannelChanged(int channel)
 
 void AdjustLevelDialog::slotScaleChanged(int scale)
 {
-    switch(scale)
-       {
-       case Linear: 
-          m_histogramWidget->m_scaleType = Digikam::HistogramWidget::LinScaleHistogram;
-          break;
-       
-       case Logarithmic:
-          m_histogramWidget->m_scaleType = Digikam::HistogramWidget::LogScaleHistogram;
-          break;
-       }
-
+    m_histogramWidget->m_scaleType = scale;
     m_histogramWidget->repaint(false);
 }
 
-void AdjustLevelDialog::slotLoadLevels()
+// Reset all settings.
+void AdjustLevelDialog::slotDefault()
+{
+    for (int channel = 0 ; channel < 5 ; ++channel)
+       m_levels->levelsChannelReset(channel);
+
+    // Refresh the current levels config.
+    slotChannelChanged(m_channelCB->currentItem());
+    m_histogramWidget->reset();
+    
+    slotEffect();
+}
+
+// Load all settings.
+void AdjustLevelDialog::slotUser3()
 {
     KURL loadLevelsFile;
 
@@ -692,7 +650,8 @@ void AdjustLevelDialog::slotLoadLevels()
     slotChannelChanged(m_channelCB->currentItem());
 }
 
-void AdjustLevelDialog::slotSaveLevels()
+// Save all settings.
+void AdjustLevelDialog::slotUser2()
 {
     KURL saveLevelsFile;
 
