@@ -37,6 +37,7 @@
 #include <qgroupbox.h>
 #include <qhgroupbox.h>
 #include <qvgroupbox.h>
+#include <qhbuttongroup.h> 
 #include <qlabel.h>
 #include <qpainter.h>
 #include <qcombobox.h>
@@ -79,18 +80,15 @@ namespace DigikamChannelMixerImagesPlugin
 {
 
 ChannelMixerDialog::ChannelMixerDialog(QWidget* parent, uint *imageData, uint width, uint height)
-                  : KDialogBase(Plain, i18n("Color Channel Mixer"), Help|User1|Ok|Cancel, Ok,
-                                parent, 0, true, true, i18n("&Reset Values"))
+                  : ImageTabDialog(parent, i18n("Color Channel Mixer"), "channelmixer", 
+                                   true, false, true)
 {
     m_destinationPreviewData = 0L;
-    parentWidget()->setCursor( KCursor::waitCursor() );
     
-    setButtonWhatsThis ( User1, i18n("<p>Reset color channels' gains settings from the current selected channel.") );
-
     // About data and help button.
 
     KAboutData* about = new KAboutData("digikamimageplugins",
-                                       I18N_NOOP("Channel Mixer"),
+                                       I18N_NOOP("Color Channel Mixer"),
                                        digikamimageplugins_version,
                                        I18N_NOOP("An image color channel mixer plugin for digiKam."),
                                        KAboutData::License_GPL,
@@ -101,49 +99,16 @@ ChannelMixerDialog::ChannelMixerDialog(QWidget* parent, uint *imageData, uint wi
     about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
                      "caulier dot gilles at free.fr");
 
-    m_helpButton = actionButton( Help );
-    KHelpMenu* helpMenu = new KHelpMenu(this, about, false);
-    helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Channel Mixer Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
-    m_helpButton->setPopup( helpMenu->menu() );
-
+    setAboutData(about);
+    
     // -------------------------------------------------------------
 
-    QGridLayout* topLayout = new QGridLayout( plainPage(), 3, 2 , marginHint(), spacingHint());
+    QWidget *gboxSettings = new QWidget(plainPage());
+    QGridLayout* grid = new QGridLayout( gboxSettings, 10, 4, marginHint(), spacingHint());
 
-    QFrame *headerFrame = new QFrame( plainPage() );
-    headerFrame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QHBoxLayout* layout = new QHBoxLayout( headerFrame );
-    layout->setMargin( 2 ); // to make sure the frame gets displayed
-    layout->setSpacing( 0 );
-    QLabel *pixmapLabelLeft = new QLabel( headerFrame, "pixmapLabelLeft" );
-    pixmapLabelLeft->setScaledContents( false );
-    layout->addWidget( pixmapLabelLeft );
-    QLabel *labelTitle = new QLabel( i18n("Image Color Channel Mixer"), headerFrame, "labelTitle" );
-    layout->addWidget( labelTitle );
-    layout->setStretchFactor( labelTitle, 1 );
-    topLayout->addMultiCellWidget(headerFrame, 0, 0, 0, 1);
-
-    QString directory;
-    KGlobal::dirs()->addResourceType("digikamimageplugins_banner_left", KGlobal::dirs()->kde_default("data") +
-                                                                        "digikamimageplugins/data");
-    directory = KGlobal::dirs()->findResourceDir("digikamimageplugins_banner_left",
-                                                 "digikamimageplugins_banner_left.png");
-
-    pixmapLabelLeft->setPaletteBackgroundColor( QColor(201, 208, 255) );
-    pixmapLabelLeft->setPixmap( QPixmap( directory + "digikamimageplugins_banner_left.png" ) );
-    labelTitle->setPaletteBackgroundColor( QColor(201, 208, 255) );
-
-    // -------------------------------------------------------------
-
-    QGroupBox *gbox = new QGroupBox(plainPage());
-    gbox->setFlat(false);
-    gbox->setTitle(i18n("Settings"));
-    QGridLayout* grid = new QGridLayout( gbox, 6, 5, 20, spacingHint());
-
-    QLabel *label1 = new QLabel(i18n("Channel:"), gbox);
+    QLabel *label1 = new QLabel(i18n("Channel:"), gboxSettings);
     label1->setAlignment ( Qt::AlignRight | Qt::AlignVCenter );
-    m_channelCB = new QComboBox( false, gbox );
+    m_channelCB = new QComboBox( false, gboxSettings );
     m_channelCB->insertItem( i18n("Red") );
     m_channelCB->insertItem( i18n("Green") );
     m_channelCB->insertItem( i18n("Blue") );
@@ -153,119 +118,114 @@ ChannelMixerDialog::ChannelMixerDialog(QWidget* parent, uint *imageData, uint wi
                                        "<b>Green</b>: display the green image-channel values.<p>"
                                        "<b>Blue</b>: display the blue image-channel values.<p>"));
 
-    QLabel *label2 = new QLabel(i18n("Scale:"), gbox);
-    label2->setAlignment ( Qt::AlignRight | Qt::AlignVCenter);
-    m_scaleCB = new QComboBox( false, gbox );
-    m_scaleCB->insertItem( i18n("Linear") );
-    m_scaleCB->insertItem( i18n("Logarithmic") );
-    m_scaleCB->setCurrentText( i18n("Logarithmic") );
-    QWhatsThis::add( m_scaleCB, i18n("<p>Select here the histogram scale.<p>"
+    m_scaleBG = new QHButtonGroup(gboxSettings);
+    m_scaleBG->setExclusive(true);
+    m_scaleBG->setFrameShape(QFrame::NoFrame);
+    m_scaleBG->setInsideMargin( 0 );
+    QWhatsThis::add( m_scaleBG, i18n("<p>Select here the histogram scale.<p>"
                                      "If the image's maximal counts are small, you can use the linear scale.<p>"
                                      "Logarithmic scale can be used when the maximal counts are big; "
                                      "if it is used, all values (small and large) will be visible on the graph."));
+    
+    QPushButton *linHistoButton = new QPushButton( m_scaleBG );
+    QToolTip::add( linHistoButton, i18n( "<p>Linear" ) );
+    m_scaleBG->insert(linHistoButton, Digikam::HistogramWidget::LinScaleHistogram);
+    KGlobal::dirs()->addResourceType("histogram-lin", KGlobal::dirs()->kde_default("data") + "digikam/data");
+    QString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
+    linHistoButton->setPixmap( QPixmap( directory + "histogram-lin.png" ) );
+    linHistoButton->setToggleButton(true);
+    
+    QPushButton *logHistoButton = new QPushButton( m_scaleBG );
+    QToolTip::add( logHistoButton, i18n( "<p>Logarithmic" ) );
+    m_scaleBG->insert(logHistoButton, Digikam::HistogramWidget::LogScaleHistogram);
+    KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
+    logHistoButton->setPixmap( QPixmap( directory + "histogram-log.png" ) );
+    logHistoButton->setToggleButton(true);       
 
-    grid->addMultiCellWidget(label1, 0, 0, 0, 0);
-    grid->addMultiCellWidget(m_channelCB, 0, 0, 1, 1);
-    grid->addMultiCellWidget(label2, 0, 0, 3, 3);
-    grid->addMultiCellWidget(m_scaleCB, 0, 0, 4, 4);
+    QHBoxLayout* l1 = new QHBoxLayout();
+    l1->addWidget(label1);
+    l1->addWidget(m_channelCB);
+    l1->addWidget(m_scaleBG);
+    l1->addStretch(10);
+    
+    grid->addMultiCellLayout(l1, 0, 0, 0, 4);
 
-    QFrame *frame = new QFrame(gbox);
-    frame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QVBoxLayout* l = new QVBoxLayout(frame, 5, 0);
-
-    m_histogramWidget = new Digikam::HistogramWidget(256, 140, imageData, width, height, frame, false, true, true);
+    m_histogramWidget = new Digikam::HistogramWidget(256, 140, imageData, width, height, gboxSettings, false, true, true);
     QWhatsThis::add( m_histogramWidget, i18n("<p>Here you can see the target preview image histogram drawing of the "
                                              "selected image channel. This one is re-computed at any mixer "
                                              "settings changes."));
-    l->addWidget(m_histogramWidget, 0);
-    grid->addMultiCellWidget(frame, 1, 1, 0, 4);
     
-    m_hGradient = new Digikam::ColorGradientWidget( KSelector::Horizontal, 20, gbox );
+    m_hGradient = new Digikam::ColorGradientWidget( Digikam::ColorGradientWidget::Horizontal, 10, gboxSettings );
     m_hGradient->setColors( QColor( "black" ), QColor( "red" ) );
-
-    QLabel *redLabel = new QLabel(i18n("Red:"), gbox);
-    m_redGain = new KDoubleNumInput(gbox);
+    
+    grid->addMultiCellWidget(m_histogramWidget, 1, 1, 0, 4);
+    grid->addMultiCellWidget(m_hGradient, 2, 2, 0, 4);
+    
+    // -------------------------------------------------------------
+        
+    QLabel *redLabel = new QLabel(i18n("Red:"), gboxSettings);
+    m_redGain = new KDoubleNumInput(gboxSettings);
     m_redGain->setPrecision(0);
     m_redGain->setRange(-200.0, 200.0, 1, true);
     QWhatsThis::add( m_redGain, i18n("<p>Select here the red color gain in percent for the current channel."));
     
-    QLabel *blueLabel = new QLabel(i18n("Blue:"), gbox);
-    m_greenGain = new KDoubleNumInput(gbox);
+    QLabel *blueLabel = new QLabel(i18n("Blue:"), gboxSettings);
+    m_greenGain = new KDoubleNumInput(gboxSettings);
     m_greenGain->setPrecision(0);
     m_greenGain->setRange(-200.0, 200.0, 1, true);
     QWhatsThis::add( m_greenGain, i18n("<p>Select here the green color gain in percent for the current channel."));
     
-    QLabel *greenLabel = new QLabel(i18n("Green:"), gbox);
-    m_blueGain = new KDoubleNumInput(gbox);
+    QLabel *greenLabel = new QLabel(i18n("Green:"), gboxSettings);
+    m_blueGain = new KDoubleNumInput(gboxSettings);
     m_blueGain->setPrecision(0);
     m_blueGain->setRange(-200.0, 200.0, 1, true);
     QWhatsThis::add( m_blueGain, i18n("<p>Select here the blue color gain in percent for the current channel."));
 
-    grid->addMultiCellWidget(m_hGradient, 2, 2, 0, 4);
+    m_resetButton = new QPushButton(i18n("&Reset"), gboxSettings);
+    QWhatsThis::add( m_resetButton, i18n("Reset color channels' gains settings from the currently selected channel."));
+
     grid->addMultiCellWidget(redLabel, 3, 3, 0, 0);
     grid->addMultiCellWidget(greenLabel, 4, 4, 0, 0);
     grid->addMultiCellWidget(blueLabel, 5, 5, 0, 0);
     grid->addMultiCellWidget(m_redGain, 3, 3, 1, 4);
     grid->addMultiCellWidget(m_greenGain, 4, 4, 1, 4);
     grid->addMultiCellWidget(m_blueGain, 5, 5, 1, 4);
+    grid->addMultiCellWidget(m_resetButton, 6, 6, 0, 1);
 
-    m_monochrome = new QCheckBox( i18n("Monochrome"), gbox);
-    QWhatsThis::add( m_monochrome, i18n("<p>Enable this option if you want rendering the image in monochrome mode. "
+    // -------------------------------------------------------------
+    
+    m_monochrome = new QCheckBox( i18n("Monochrome"), gboxSettings);
+    QWhatsThis::add( m_monochrome, i18n("<p>Enable this option if you want rendering of the image in monochrome mode. "
                                         "In this mode, histogram will display only luminosity values."));
     
-    m_preserveLuminosity = new QCheckBox( i18n("Preserve luminosity"), gbox);
+    m_preserveLuminosity = new QCheckBox( i18n("Preserve luminosity"), gboxSettings);
     QWhatsThis::add( m_preserveLuminosity, i18n("<p>Enable this option is you want preserve the image luminosity."));
     
-    grid->addMultiCellWidget(m_monochrome, 6, 6, 0, 1);
-    grid->addMultiCellWidget(m_preserveLuminosity, 6, 6, 3, 4);
+    m_overExposureIndicatorBox = new QCheckBox(i18n("Over exposure indicator"), gboxSettings);
+    QWhatsThis::add( m_overExposureIndicatorBox, i18n("<p>If you enable this option, over-exposed pixels "
+                                                      "from the target image preview will be over-colored. "
+                                                      "This will not have an effect on the final rendering."));
+    
+    grid->addMultiCellWidget(m_monochrome, 7, 7, 0, 4);
+    grid->addMultiCellWidget(m_preserveLuminosity, 8, 8, 0, 4);
+    grid->addMultiCellWidget(m_overExposureIndicatorBox, 9, 9, 0, 4);
+    grid->setRowStretch(10, 10);
+    
+    setUserAreaWidget(gboxSettings);
     
-    topLayout->addMultiCellWidget(gbox, 1, 1, 0, 0);
-
     // -------------------------------------------------------------
 
-    QHGroupBox *gbox3 = new QHGroupBox(i18n("All Channels' Gains"), plainPage());
-    m_loadButton = new QPushButton(i18n("&Load..."), gbox3);
-    QWhatsThis::add( m_loadButton, i18n("<p>Load gains settings from a Gimp gains text file."));
-    m_saveButton = new QPushButton(i18n("&Save As..."), gbox3);
-    QWhatsThis::add( m_saveButton, i18n("<p>Save gains settings to a Gimp gains text file."));
-    m_resetButton = new QPushButton(i18n("&Reset All"), gbox3);
-    QWhatsThis::add( m_resetButton, i18n("<p>Reset all color channels' gains settings."));
-
-    topLayout->addMultiCellWidget(gbox3, 3, 3, 0, 0);
-
-    // -------------------------------------------------------------
-
-    QVGroupBox *gbox4 = new QVGroupBox(i18n("Preview"), plainPage());
-
-    QFrame *frame2 = new QFrame(gbox4);
-    frame2->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QVBoxLayout* l2  = new QVBoxLayout(frame2, 5, 0);
-    m_previewOriginalWidget = new Digikam::ImageWidget(300, 200, frame2);
-    QWhatsThis::add( m_previewOriginalWidget, i18n("<p>You can see here the original image."));
-    l2->addWidget(m_previewOriginalWidget, 0, Qt::AlignCenter);
-
-    QFrame *frame3 = new QFrame(gbox4);
-    frame3->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QVBoxLayout* l3  = new QVBoxLayout(frame3, 5, 0);
-    m_previewTargetWidget = new Digikam::ImageGuideWidget(300, 200, frame3, true, 
-                                                          Digikam::ImageGuideWidget::PickColorMode);
+    m_previewOriginalWidget = previewOriginalWidget();
+    m_previewTargetWidget   = previewTargetWidget();
     QWhatsThis::add( m_previewTargetWidget, i18n("<p>You can see here the image's color channels' "
                                                  "gains adjustments preview. You can pick color on image "
                                                  "to see the color level corresponding on histogram."));
-    l3->addWidget(m_previewTargetWidget, 0, Qt::AlignCenter);
-
-    m_overExposureIndicatorBox = new QCheckBox(i18n("Over exposure indicator"), gbox4);
-    QWhatsThis::add( m_overExposureIndicatorBox, i18n("<p>If you enable this option, over-exposed pixels from the target image preview "
-                                                      "will be over-colored. This will not have an effect on the final rendering."));
     
-    topLayout->addMultiCellWidget(gbox4, 1, 3, 1, 1);
+    // -------------------------------------------------------------
 
-    adjustSize();
-    disableResize();
-
-    parentWidget()->setCursor( KCursor::arrowCursor()  );
-
-    QTimer::singleShot(0, this, SLOT(slotResetAllGains())); // Reset all parameters to the default values.
+    // Reset all parameters to the default values.
+    QTimer::singleShot(0, this, SLOT(slotDefault()));
                     
     // -------------------------------------------------------------
     // Channels and scale selection slots.
@@ -273,14 +233,17 @@ ChannelMixerDialog::ChannelMixerDialog(QWidget* parent, uint *imageData, uint wi
     connect(m_channelCB, SIGNAL(activated(int)),
             this, SLOT(slotChannelChanged(int)));
 
-    connect(m_scaleCB, SIGNAL(activated(int)),
+    connect(m_scaleBG, SIGNAL(released(int)),
             this, SLOT(slotScaleChanged(int)));
 
     connect(m_previewTargetWidget, SIGNAL(spotPositionChanged( const QColor &, bool, const QPoint & )),
             this, SLOT(slotColorSelectedFromTarget( const QColor & ))); 
                         
     connect(m_overExposureIndicatorBox, SIGNAL(toggled (bool)),
-            this, SLOT(slotEffect()));              
+            this, SLOT(slotEffect()));
+    
+    connect(m_previewTargetWidget, SIGNAL(signalResized()),
+            this, SLOT(slotEffect()));                             
     
     // -------------------------------------------------------------
     // Gains settings slots.
@@ -304,25 +267,10 @@ ChannelMixerDialog::ChannelMixerDialog(QWidget* parent, uint *imageData, uint wi
     // Bouttons slots.
 
     connect(m_resetButton, SIGNAL(clicked()),
-            this, SLOT(slotResetAllGains()));
-
-    connect(m_loadButton, SIGNAL(clicked()),
-            this, SLOT(slotLoadGains()));
-
-    connect(m_saveButton, SIGNAL(clicked()),
-            this, SLOT(slotSaveGains()));
+            this, SLOT(slotResetCurrentChannel()));
 }
 
 ChannelMixerDialog::~ChannelMixerDialog()
-{
-}
-
-void ChannelMixerDialog::slotHelp()
-{
-    KApplication::kApplication()->invokeHelp("channelmixer", "digikamimageplugins");
-}
-
-void ChannelMixerDialog::closeEvent(QCloseEvent *e)
 {
     m_histogramWidget->stopHistogramComputation();
 
@@ -330,44 +278,9 @@ void ChannelMixerDialog::closeEvent(QCloseEvent *e)
        delete [] m_destinationPreviewData;
        
     delete m_histogramWidget;
-    e->accept();
 }
 
-void ChannelMixerDialog::slotResetAllGains()
-{
-    m_redRedGain = 1.0; 
-    m_redGreenGain = 0.0; 
-    m_redBlueGain = 0.0; 
-    
-    m_greenRedGain = 0.0;
-    m_greenGreenGain = 1.0; 
-    m_greenBlueGain = 0.0;
-    
-    m_blueRedGain = 0.0;
-    m_blueGreenGain = 0.0;
-    m_blueBlueGain = 1.0;
-
-    m_blackRedGain = 1.0; 
-    m_blackGreenGain = 0.0; 
-    m_blackBlueGain = 0.0; 
-    
-    m_monochrome->blockSignals(true);
-    m_preserveLuminosity->blockSignals(true);
-    
-    m_monochrome->setChecked( false );
-    m_preserveLuminosity->setChecked( false );
-    adjustSliders();
-    
-    m_monochrome->blockSignals(false);
-    m_preserveLuminosity->blockSignals(false);
-    m_channelCB->setEnabled(true);
-    
-    m_histogramWidget->reset();
-
-    slotEffect();
-}
-
-void ChannelMixerDialog::slotUser1()
+void ChannelMixerDialog::slotResetCurrentChannel()
 {
     switch( m_channelCB->currentItem() )
        {
@@ -494,13 +407,11 @@ void ChannelMixerDialog::slotMonochromeActived(bool mono)
 
 void ChannelMixerDialog::slotEffect()
 {
-    Digikam::ImageIface* ifaceOrg = m_previewOriginalWidget->imageIface();
-
     Digikam::ImageIface* ifaceDest = m_previewTargetWidget->imageIface();
 
-    uint* orgData = ifaceOrg->getPreviewData();
-    int   w       = ifaceOrg->previewWidth();
-    int   h       = ifaceOrg->previewHeight();
+    uint* orgData = ifaceDest->getPreviewData();
+    int   w       = ifaceDest->previewWidth();
+    int   h       = ifaceDest->previewHeight();
     bool  l       = m_preserveLuminosity->isChecked();
     bool  m       = m_monochrome->isChecked();
 
@@ -536,7 +447,7 @@ void ChannelMixerDialog::slotEffect()
        }
     
     ifaceDest->putPreviewData(m_destinationPreviewData);
-    m_previewTargetWidget->update();
+    m_previewTargetWidget->updatePreview();
     
     // Update histogram.
     m_histogramWidget->updateData(m_destinationPreviewData, w, h, 0, 0, 0, false); 
@@ -546,13 +457,12 @@ void ChannelMixerDialog::slotEffect()
 
 void ChannelMixerDialog::slotOk()
 {
-    Digikam::ImageIface* ifaceOrg = m_previewOriginalWidget->imageIface();
+    kapp->setOverrideCursor( KCursor::waitCursor() );
+    Digikam::ImageIface ifaceDest(0, 0);
 
-    Digikam::ImageIface* ifaceDest = m_previewTargetWidget->imageIface();
-
-    uint* orgData = ifaceOrg->getOriginalData();
-    int   w       = ifaceOrg->originalWidth();
-    int   h       = ifaceOrg->originalHeight();
+    uint* orgData = ifaceDest.getOriginalData();
+    int   w       = ifaceDest.originalWidth();
+    int   h       = ifaceDest.originalHeight();
     bool  l       = m_preserveLuminosity->isChecked();
     bool  m       = m_monochrome->isChecked();
 
@@ -580,7 +490,8 @@ void ChannelMixerDialog::slotOk()
                 m_blueRedGain,  m_blueGreenGain,  m_blueBlueGain);  // Blue channel gains.
        }
     
-    ifaceDest->putOriginalData(i18n("Channel Mixer"), desData);
+    ifaceDest.putOriginalData(i18n("Channel Mixer"), desData);
+    kapp->restoreOverrideCursor();
 
     delete [] orgData;
     delete [] desData;
@@ -622,21 +533,46 @@ void ChannelMixerDialog::slotChannelChanged(int channel)
 
 void ChannelMixerDialog::slotScaleChanged(int scale)
 {
-    switch(scale)
-       {
-       case Linear:
-          m_histogramWidget->m_scaleType = Digikam::HistogramWidget::LinScaleHistogram;
-          break;
-       
-       case Logarithmic:
-          m_histogramWidget->m_scaleType = Digikam::HistogramWidget::LogScaleHistogram;
-          break;
-       }
-
+    m_histogramWidget->m_scaleType = scale;
     m_histogramWidget->repaint(false);
 }
 
-void ChannelMixerDialog::slotLoadGains()
+// Reset all gains.
+void ChannelMixerDialog::slotDefault()
+{
+    m_monochrome->blockSignals(true);
+    m_preserveLuminosity->blockSignals(true);
+    
+    m_redRedGain = 1.0; 
+    m_redGreenGain = 0.0; 
+    m_redBlueGain = 0.0; 
+    
+    m_greenRedGain = 0.0;
+    m_greenGreenGain = 1.0; 
+    m_greenBlueGain = 0.0;
+    
+    m_blueRedGain = 0.0;
+    m_blueGreenGain = 0.0;
+    m_blueBlueGain = 1.0;
+
+    m_blackRedGain = 1.0; 
+    m_blackGreenGain = 0.0; 
+    m_blackBlueGain = 0.0; 
+
+    adjustSliders();
+    
+    m_monochrome->blockSignals(false);
+    m_preserveLuminosity->blockSignals(false);
+    m_channelCB->setEnabled(true);
+    
+    m_histogramWidget->reset();
+
+    slotChannelChanged(RedChannelGains);
+    slotEffect();
+}
+
+// Load all gains.
+void ChannelMixerDialog::slotUser3()
 {
     KURL loadGainsFileUrl;
     FILE *fp = 0L;
@@ -676,14 +612,14 @@ void ChannelMixerDialog::slotLoadGains()
 
         fscanf (fp, "%*s %s", buf1);
           
-        if (strcmp (buf1, "TRUE") == 0)
+        if (strcmp (buf1, "true") == 0)
             monochrome = true;
         else
             monochrome = false;
 
         fscanf (fp, "%*s %s", buf1);
         
-        if (strcmp (buf1, "TRUE") == 0)
+        if (strcmp (buf1, "true") == 0)
             m_preserveLuminosity->setChecked(true);
         else
             m_preserveLuminosity->setChecked(false);
@@ -722,7 +658,8 @@ void ChannelMixerDialog::slotLoadGains()
         }
 }
 
-void ChannelMixerDialog::slotSaveGains()
+// Save all gains.
+void ChannelMixerDialog::slotUser2()
 {
     KURL saveGainsFileUrl;
     FILE *fp = 0L;
@@ -761,11 +698,11 @@ void ChannelMixerDialog::slotSaveGains()
         fprintf (fp, "# Channel Mixer Configuration File\n");
 
         fprintf (fp, "CHANNEL: %s\n", str);
-        fprintf (fp, "PREVIEW: %s\n", "TRUE"); // preserved for compatibility 
+        fprintf (fp, "PREVIEW: %s\n", "true"); // preserved for compatibility 
         fprintf (fp, "MONOCHROME: %s\n",
-                 m_monochrome->isChecked() ? "TRUE" : "FALSE");
+                 m_monochrome->isChecked() ? "true" : "false");
         fprintf (fp, "PRESERVE_LUMINOSITY: %s\n",
-                 m_preserveLuminosity->isChecked() ? "TRUE" : "FALSE");
+                 m_preserveLuminosity->isChecked() ? "true" : "false");
 
         sprintf (buf1, "%5.3f", m_redRedGain);                 
         sprintf (buf2, "%5.3f", m_redGreenGain);
