@@ -41,6 +41,7 @@
 #include <qvgroupbox.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
+#include <qhbuttongroup.h> 
 #include <qwhatsthis.h>
 #include <qlayout.h>
 #include <qframe.h>
@@ -68,6 +69,7 @@
 #include <kglobalsettings.h>
 #include <kdebug.h>
 #include <kfiledialog.h>
+#include <kseparator.h>
 
 // Digikam includes.
 
@@ -83,20 +85,11 @@ namespace DigikamWhiteBalanceImagesPlugin
 {
 
 ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageData, uint width, uint height)
-                        : KDialogBase(Plain, i18n("White Balance"),
-                                      Help|User1|User2|User3|Ok|Cancel, Ok,
-                                      parent, 0, true, true,
-                                      i18n("&Reset Values"),
-                                      i18n("&Load..."),
-                                      i18n("&Save As...")),
-                          m_parent(parent)
+                        : ImageTabDialog(parent, i18n("White Color Balance Correction"), "whitebalance",
+                                         true, true, true)
 {
-    parentWidget()->setCursor( KCursor::waitCursor() );
     QString whatsThis;
-    setButtonWhatsThis ( User1, i18n("<p>Reset all parameters to the default values.") );
-    setButtonWhatsThis ( User2, i18n("<p>Load all parameters from settings text file.") );
-    setButtonWhatsThis ( User3, i18n("<p>Save all parameters to settings text file.") );    
-
+    
     m_originalImageData = imageData;
     m_originalWidth     = width;
     m_originalHeight    = height;
@@ -115,7 +108,7 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
     // About data and help button.
     
     KAboutData* about = new KAboutData("digikamimageplugins",
-                                       I18N_NOOP("White Balance"), 
+                                       I18N_NOOP("White Color Balance Correction"), 
                                        digikamimageplugins_version,
                                        I18N_NOOP("A digiKam image plugin to correct white color balance."),
                                        KAboutData::License_GPL,
@@ -126,53 +119,21 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
     about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
                      "caulier dot gilles at free.fr");
     
-    about->addAuthor("Pawel T. Jochym", I18N_NOOP("White color balance algorithm"),
+    about->addAuthor("Pawel T. Jochym", I18N_NOOP("White color balance correction algorithm"),
                      "jochym at ifj edu pl");
     
-    m_helpButton = actionButton( Help );
-    KHelpMenu* helpMenu = new KHelpMenu(this, about, false);
-    helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("White Balance Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
-    m_helpButton->setPopup( helpMenu->menu() );
-    
-    // -------------------------------------------------------------
-
-    QGridLayout* topLayout = new QGridLayout( plainPage(), 2, 2 , marginHint(), spacingHint());
-
-    QFrame *headerFrame = new QFrame( plainPage() );
-    headerFrame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QHBoxLayout* layout = new QHBoxLayout( headerFrame );
-    layout->setMargin( 2 ); // to make sure the frame gets displayed
-    layout->setSpacing( 0 );
-    QLabel *pixmapLabelLeft = new QLabel( headerFrame, "pixmapLabelLeft" );
-    pixmapLabelLeft->setScaledContents( false );
-    layout->addWidget( pixmapLabelLeft );
-    QLabel *labelTitle = new QLabel( i18n("White Color Balance Correction"), headerFrame, "labelTitle" );
-    layout->addWidget( labelTitle );
-    layout->setStretchFactor( labelTitle, 1 );
-    topLayout->addMultiCellWidget(headerFrame, 0, 0, 0, 1);
-
-    QString directory;
-    KGlobal::dirs()->addResourceType("digikamimageplugins_banner_left", KGlobal::dirs()->kde_default("data") +
-                                                                        "digikamimageplugins/data");
-    directory = KGlobal::dirs()->findResourceDir("digikamimageplugins_banner_left",
-                                                 "digikamimageplugins_banner_left.png");
-    
-    pixmapLabelLeft->setPaletteBackgroundColor( QColor(201, 208, 255) );
-    pixmapLabelLeft->setPixmap( QPixmap( directory + "digikamimageplugins_banner_left.png" ) );
-    labelTitle->setPaletteBackgroundColor( QColor(201, 208, 255) );
+    setAboutData(about);
     
     // -------------------------------------------------------------
     
-    QGroupBox *gbox = new QGroupBox(i18n("Settings"), plainPage());
-    gbox->setFlat(false);
-    QVBoxLayout* layout2 = new QVBoxLayout( gbox, 20 );
+    QWidget *gboxSettings = new QWidget(plainPage());
+    QVBoxLayout* layout2 = new QVBoxLayout( gboxSettings, marginHint(), spacingHint() );
 
     QGridLayout *grid = new QGridLayout( layout2, 2, 4, spacingHint());
     
-    QLabel *label1 = new QLabel(i18n("Channel:"), gbox);
+    QLabel *label1 = new QLabel(i18n("Channel:"), gboxSettings);
     label1->setAlignment ( Qt::AlignRight | Qt::AlignVCenter );
-    m_channelCB = new QComboBox( false, gbox );
+    m_channelCB = new QComboBox( false, gboxSettings );
     m_channelCB->insertItem( i18n("Luminosity") );
     m_channelCB->insertItem( i18n("Red") );
     m_channelCB->insertItem( i18n("Green") );
@@ -183,102 +144,125 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
                                        "<b>Green</b>: display the green image-channel values.<p>"
                                        "<b>Blue</b>: display the blue image-channel values.<p>"));
 
-    QLabel *label2 = new QLabel(i18n("Scale:"), gbox);
-    label2->setAlignment ( Qt::AlignRight | Qt::AlignVCenter);
-    m_scaleCB = new QComboBox( false, gbox );
-    m_scaleCB->insertItem( i18n("Linear") );
-    m_scaleCB->insertItem( i18n("Logarithmic") );
-    m_scaleCB->setCurrentText( i18n("Logarithmic") );
-    QWhatsThis::add( m_scaleCB, i18n("<p>Select here the histogram scale.<p>"
+    m_scaleBG = new QHButtonGroup(gboxSettings);
+    m_scaleBG->setExclusive(true);
+    m_scaleBG->setFrameShape(QFrame::NoFrame);
+    m_scaleBG->setInsideMargin( 0 );
+    QWhatsThis::add( m_scaleBG, i18n("<p>Select here the histogram scale.<p>"
                                      "If the image's maximal counts are small, you can use the linear scale.<p>"
                                      "Logarithmic scale can be used when the maximal counts are big; "
-                                     "if it is used, all values (small and large) will be visible on the "
-                                     "graph."));
-
-    grid->addMultiCellWidget(label1, 0, 0, 0, 0);
-    grid->addMultiCellWidget(m_channelCB, 0, 0, 1, 1);
-    grid->addMultiCellWidget(label2, 0, 0, 3, 3);
-    grid->addMultiCellWidget(m_scaleCB, 0, 0, 4, 4);
-        
-    QFrame *frame = new QFrame(gbox);
-    frame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QVBoxLayout* l = new QVBoxLayout(frame, 5, 0);
-
-    m_histogramWidget = new Digikam::HistogramWidget(256, 140, m_originalImageData, m_originalWidth, m_originalHeight, frame, false, true, true);
-    QWhatsThis::add( m_histogramWidget, i18n("<p>Here you can see the target preview image histogram drawing of the "
-                                             "selected image channel. This one is re-computed at any filter "
-                                             "settings changes."));
-    l->addWidget(m_histogramWidget, 0);
-    grid->addMultiCellWidget(frame, 1, 1, 0, 4);
+                                     "if it is used, all values (small and large) will be visible on the graph."));
     
-    m_hGradient = new Digikam::ColorGradientWidget( KSelector::Horizontal, 20, gbox );
+    QPushButton *linHistoButton = new QPushButton( m_scaleBG );
+    QToolTip::add( linHistoButton, i18n( "<p>Linear" ) );
+    m_scaleBG->insert(linHistoButton, Digikam::HistogramWidget::LinScaleHistogram);
+    KGlobal::dirs()->addResourceType("histogram-lin", KGlobal::dirs()->kde_default("data") + "digikam/data");
+    QString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
+    linHistoButton->setPixmap( QPixmap( directory + "histogram-lin.png" ) );
+    linHistoButton->setToggleButton(true);
+    
+    QPushButton *logHistoButton = new QPushButton( m_scaleBG );
+    QToolTip::add( logHistoButton, i18n( "<p>Logarithmic" ) );
+    m_scaleBG->insert(logHistoButton, Digikam::HistogramWidget::LogScaleHistogram);
+    KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
+    logHistoButton->setPixmap( QPixmap( directory + "histogram-log.png" ) );
+    logHistoButton->setToggleButton(true);       
+
+    QHBoxLayout* l1 = new QHBoxLayout();
+    l1->addWidget(label1);
+    l1->addWidget(m_channelCB);
+    l1->addWidget(m_scaleBG);
+    l1->addStretch(10);
+    
+    grid->addMultiCellLayout(l1, 0, 0, 0, 4);
+        
+    m_histogramWidget = new Digikam::HistogramWidget(256, 140, m_originalImageData, 
+                                                     m_originalWidth, m_originalHeight, 
+                                                     gboxSettings, false, true, true);
+    QWhatsThis::add( m_histogramWidget, i18n("<p>Here you can see the target preview image histogram "
+                                             "drawing of the selected image channel. This one is "
+                                             "re-computed at any filter settings changes."));
+    grid->addMultiCellWidget(m_histogramWidget, 1, 1, 0, 4);
+    
+    m_hGradient = new Digikam::ColorGradientWidget( Digikam::ColorGradientWidget::Horizontal, 10, gboxSettings );
     m_hGradient->setColors( QColor( "black" ), QColor( "white" ) );
     grid->addMultiCellWidget(m_hGradient, 2, 2, 0, 4);
     
     // -------------------------------------------------------------
 
-    QGridLayout *grid2 = new QGridLayout( layout2, 6, 5, spacingHint());
+    QGridLayout *grid2 = new QGridLayout( layout2, 10, 5, spacingHint());
     KIconLoader icon;
     
-    m_exposureLabel = new QLabel(i18n("Exposure:"), gbox);
-    m_autoAdjustExposure = new QPushButton(gbox);
+    m_exposureLabel = new QLabel(i18n("Exposure:"), gboxSettings);
+    m_autoAdjustExposure = new QPushButton(gboxSettings);
     m_autoAdjustExposure->setPixmap( icon.loadIcon( "run", (KIcon::Group)KIcon::Toolbar ) );
-    QToolTip::add( m_autoAdjustExposure, i18n( "Auto Exposure adjustments." ) );
+    QToolTip::add( m_autoAdjustExposure, i18n( "Auto exposure adjustments" ) );
     QWhatsThis::add( m_autoAdjustExposure, i18n("<p>With this button, you can automatically adjust Exposure "
                                                 "and Black Point values."));
-    m_exposureInput = new KDoubleNumInput(gbox);
+    m_exposureInput = new KDoubleNumInput(gboxSettings);
     m_exposureInput->setPrecision(2);
     m_exposureInput->setRange(-6.0, 8.0, 0.01, true);
     QWhatsThis::add( m_exposureInput, i18n("<p>Set here the Exposure Value (EV)."));
     
-    m_blackLabel = new QLabel(i18n("Black point:"), gbox);
-    m_blackInput = new KDoubleNumInput(gbox);
+    m_blackLabel = new QLabel(i18n("Black point:"), gboxSettings);
+    m_blackInput = new KDoubleNumInput(gboxSettings);
     m_blackInput->setPrecision(2);
     m_blackInput->setRange(0.0, 0.05, 0.01, true);
     QWhatsThis::add( m_blackInput, i18n("<p>Set here the black level value."));
         
-    m_darkLabel = new QLabel(i18n("Shadows:"), gbox);
-    m_darkInput = new KDoubleNumInput(gbox);
+    m_darkLabel = new QLabel(i18n("Shadows:"), gboxSettings);
+    m_darkInput = new KDoubleNumInput(gboxSettings);
     m_darkInput->setPrecision(2);
     m_darkInput->setRange(0.0, 1.0, 0.01, true);
     QWhatsThis::add( m_darkInput, i18n("<p>Set here the shadows noise suppresion level."));
 
-    m_saturationLabel = new QLabel(i18n("Saturation:"), gbox);
-    m_saturationInput = new KDoubleNumInput(gbox);
+    m_saturationLabel = new QLabel(i18n("Saturation:"), gboxSettings);
+    m_saturationInput = new KDoubleNumInput(gboxSettings);
     m_saturationInput->setPrecision(2);
     m_saturationInput->setRange(0.0, 2.0, 0.01, true);
     QWhatsThis::add( m_saturationInput, i18n("<p>Set here the saturation value."));
         
-    m_gammaLabel = new QLabel(i18n("Gamma:"), gbox);
-    m_gammaInput = new KDoubleNumInput(gbox);
+    m_gammaLabel = new QLabel(i18n("Gamma:"), gboxSettings);
+    m_gammaInput = new KDoubleNumInput(gboxSettings);
     m_gammaInput->setPrecision(2);
     m_gammaInput->setRange(0.01, 1.5, 0.01, true);
     QWhatsThis::add( m_gammaInput, i18n("<p>Set here the gamma correction value."));
-        
-    m_temperatureLabel = new QLabel(i18n("Temperature:"), gbox);
-    m_temperaturePresetCB = new QComboBox( false, gbox );
-    m_temperaturePresetCB->insertItem( i18n("40W") );
-    m_temperaturePresetCB->insertItem( i18n("200W") );
+
+    KSeparator *line = new KSeparator (Horizontal, gboxSettings);
+            
+    m_temperatureLabel = new QLabel(i18n("Temperature:"), gboxSettings);
+    m_temperatureInput = new KDoubleNumInput(gboxSettings);
+    m_temperatureInput->setPrecision(1);
+    m_temperatureInput->setRange(2200.0, 7000.0, 10.0, true);
+    QWhatsThis::add( m_temperatureInput, i18n("<p>Set here the white balance color temperature in Kelvin."));
+    
+    m_temperaturePresetLabel = new QLabel(i18n("Preset:"), gboxSettings);
+    m_temperaturePresetCB = new QComboBox( false, gboxSettings );
+    m_temperaturePresetCB->insertItem( i18n("40W Lamp") );
+    m_temperaturePresetCB->insertItem( i18n("200W Lamp") );
     m_temperaturePresetCB->insertItem( i18n("Sunrise") );
-    m_temperaturePresetCB->insertItem( i18n("Tungsten") );
+    m_temperaturePresetCB->insertItem( i18n("Tungsten Lamp") );
     m_temperaturePresetCB->insertItem( i18n("Neutral") );
-    m_temperaturePresetCB->insertItem( i18n("Xenon") );
+    m_temperaturePresetCB->insertItem( i18n("Xenon Lamp") );
     m_temperaturePresetCB->insertItem( i18n("Sun") );
-    m_temperaturePresetCB->insertItem( i18n("Flash") );
+    m_temperaturePresetCB->insertItem( i18n("Photo Flash") );
     m_temperaturePresetCB->insertItem( i18n("Sky") );
     m_temperaturePresetCB->insertItem( i18n("None") );
-    QWhatsThis::add( m_temperaturePresetCB, i18n("<p>Select here the white balance color temperature preset to use:<p>"
-                                                 "<b>40W</b>: 40 Watt incandescent lamp (2680K).<p>"
-                                                 "<b>200W</b>: 200 Watt incandescent lamp (3000K).<p>"
+    QWhatsThis::add( m_temperaturePresetCB, i18n("<p>Select here the white balance color temperature "
+                                                 "preset to use:<p>"
+                                                 "<b>40W Lamp</b>: 40 Watt incandescent lamp (2680K).<p>"
+                                                 "<b>200W Lamp</b>: 200 Watt incandescent lamp (3000K).<p>"
                                                  "<b>Sunrise</b>: sunrise or sunset light (3200K).<p>"
-                                                 "<b>Tungsten</b>: tungsten lamp or light at 1 hour from dusk/dawn (3400K).<p>"
+                                                 "<b>Tungsten Lamp</b>: tungsten lamp or light at 1 hour from "
+                                                 "dusk/dawn (3400K).<p>"
                                                  "<b>Neutral</b>: neutral color temperature (4750K).<p>"
-                                                 "<b>Xenon</b>: xenon lamp or light arc (5000K).<p>"
+                                                 "<b>Xenon Lamp</b>: xenon lamp or light arc (5000K).<p>"
                                                  "<b>Sun</b>: sunny daylight around noon (5500K).<p>"
-                                                 "<b>Flash</b>: electronic photo flash (5600K).<p>"
+                                                 "<b>Photo Flash</b>: electronic photo flash (5600K).<p>"
                                                  "<b>Sky</b>: overcast sky light (6500K).<p>"
                                                  "<b>None</b>: no preset value."));
-    m_pickTemperature = new QPushButton(gbox);
+    m_pickTemperature = new QPushButton(gboxSettings);
     KGlobal::dirs()->addResourceType("color-picker-gray", KGlobal::dirs()->kde_default("data") + "digikamimageplugins/data");
     directory = KGlobal::dirs()->findResourceDir("color-picker-gray", "color-picker-gray.png");
     m_pickTemperature->setPixmap( QPixmap( directory + "color-picker-gray.png" ) );
@@ -286,80 +270,67 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
     QToolTip::add( m_pickTemperature, i18n( "Temperature tone color picker." ) );
     QWhatsThis::add( m_pickTemperature, i18n("<p>With this button, you can pick the color from original image used to set "
                                              "white color balance temperature and green component."));
-    m_temperatureInput = new KDoubleNumInput(gbox);
-    m_temperatureInput->setPrecision(1);
-    m_temperatureInput->setRange(2200.0, 7000.0, 10.0, true);
-    QWhatsThis::add( m_temperatureInput, i18n("<p>Set here the white balance color temperature in Kelvin."));
         
-    m_greenLabel = new QLabel(i18n("Green:"), gbox);
-    m_greenInput = new KDoubleNumInput(gbox);
+    m_greenLabel = new QLabel(i18n("Green:"), gboxSettings);
+    m_greenInput = new KDoubleNumInput(gboxSettings);
     m_greenInput->setPrecision(2);
     m_greenInput->setRange(1.0, 2.5, 0.01, true);
     QWhatsThis::add( m_greenInput, i18n("<p>Set here the green component to set magenta color cast removal level."));
-        
-    grid2->addMultiCellWidget(m_exposureLabel, 0, 0, 0, 0);
-    grid2->addMultiCellWidget(m_autoAdjustExposure, 0, 0, 1, 1);
-    grid2->addMultiCellWidget(m_exposureInput, 0, 0, 2, 5);
-    grid2->addMultiCellWidget(m_blackLabel, 1, 1, 0, 0);
-    grid2->addMultiCellWidget(m_blackInput, 1, 1, 1, 5);
-    grid2->addMultiCellWidget(m_darkLabel, 2, 2, 0, 0);
-    grid2->addMultiCellWidget(m_darkInput, 2, 2, 1, 5);
-    grid2->addMultiCellWidget(m_saturationLabel, 3, 3, 0, 0);
-    grid2->addMultiCellWidget(m_saturationInput, 3, 3, 1, 5);
-    grid2->addMultiCellWidget(m_gammaLabel, 4, 4, 0, 0);
-    grid2->addMultiCellWidget(m_gammaInput, 4, 4, 1, 5);
-    grid2->addMultiCellWidget(m_temperatureLabel, 5, 5, 0, 0);
-    grid2->addMultiCellWidget(m_temperaturePresetCB, 5, 5, 1, 2);
-    grid2->addMultiCellWidget(m_pickTemperature, 5, 5, 3, 3);
-    grid2->addMultiCellWidget(m_temperatureInput, 5, 5, 4, 5);
-    grid2->addMultiCellWidget(m_greenLabel, 6, 6, 0, 0);
-    grid2->addMultiCellWidget(m_greenInput, 6, 6, 1, 5);
-        
-    topLayout->addMultiCellWidget(gbox, 1, 1, 0, 0);
-        
+
+    m_overExposureIndicatorBox = new QCheckBox(i18n("Over exposure indicator"), gboxSettings);
+    QWhatsThis::add( m_overExposureIndicatorBox, i18n("<p>If you enable this option, over-exposed pixels "
+                                                      "from the target image preview will be over-colored. "
+                                                      "This will not have an effect on the final rendering."));
+                                                                  
+    grid2->addMultiCellWidget(m_temperatureLabel, 0, 0, 0, 0);
+    grid2->addMultiCellWidget(m_pickTemperature, 0, 0, 1, 1);
+    grid2->addMultiCellWidget(m_temperatureInput, 0, 0, 2, 5);
+    grid2->addMultiCellWidget(m_temperaturePresetLabel, 1, 1, 0, 0);
+    grid2->addMultiCellWidget(m_temperaturePresetCB, 1, 1, 2, 5);
+    
+    grid2->addMultiCellWidget(line, 2, 2, 0, 5);
+    
+    grid2->addMultiCellWidget(m_blackLabel, 3, 3, 0, 0);
+    grid2->addMultiCellWidget(m_blackInput, 3, 3, 1, 5);
+    grid2->addMultiCellWidget(m_darkLabel, 4, 4, 0, 0);
+    grid2->addMultiCellWidget(m_darkInput, 4, 4, 1, 5);
+    grid2->addMultiCellWidget(m_saturationLabel, 5, 5, 0, 0);
+    grid2->addMultiCellWidget(m_saturationInput, 5, 5, 1, 5);
+    grid2->addMultiCellWidget(m_gammaLabel, 6, 6, 0, 0);
+    grid2->addMultiCellWidget(m_gammaInput, 6, 6, 1, 5);
+    grid2->addMultiCellWidget(m_greenLabel, 7, 7, 0, 0);
+    grid2->addMultiCellWidget(m_greenInput, 7, 7, 1, 5);
+    grid2->addMultiCellWidget(m_exposureLabel, 8, 8, 0, 0);
+    grid2->addMultiCellWidget(m_autoAdjustExposure, 8, 8, 1, 1);
+    grid2->addMultiCellWidget(m_exposureInput, 8, 8, 2, 5);
+    grid2->addMultiCellWidget(m_overExposureIndicatorBox, 9, 9, 0, 5);
+
+    grid2->setRowStretch(10, 10);
+            
+    setUserAreaWidget(gboxSettings);
+            
     // -------------------------------------------------------------
     
-    QVGroupBox *gbox4 = new QVGroupBox(i18n("Preview"), plainPage());
-    
-    QFrame *frame2 = new QFrame(gbox4);
-    frame2->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QVBoxLayout* l2  = new QVBoxLayout(frame2, 5, 0);
-    m_previewOriginalWidget = new Digikam::ImageGuideWidget(300, 200, frame2, true, 
-                                                            Digikam::ImageGuideWidget::PickColorMode);
-    QWhatsThis::add( m_previewOriginalWidget, i18n("<p>You can see here the original image. You can pick color on image "
-                                                   "to select the tone to adjust image's white-balance with "
-                                                   "<b>Color Picker</b> method."));
-    l2->addWidget(m_previewOriginalWidget, 0, Qt::AlignCenter);
-
-    QFrame *frame3 = new QFrame(gbox4);
-    frame3->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-    QVBoxLayout* l3  = new QVBoxLayout(frame3, 5, 0);
-    m_previewTargetWidget = new Digikam::ImageGuideWidget(300, 200, frame3, true, 
-                                                          Digikam::ImageGuideWidget::PickColorMode);
-    QWhatsThis::add( m_previewTargetWidget, i18n("<p>You can see here the image's white-balance adjustments preview. "
-                                                 "You can pick color on image to see the color level corresponding on "
-                                                 "histogram."));
-    l3->addWidget(m_previewTargetWidget, 0, Qt::AlignCenter);
-    
-    m_overExposureIndicatorBox = new QCheckBox(i18n("Over exposure indicator"), gbox4);
-    QWhatsThis::add( m_overExposureIndicatorBox, i18n("<p>If you enable this option, over-exposed pixels from the target image preview "
-                                                      "will be over-colored. This will not have an effect on the final rendering."));
-
-    topLayout->addMultiCellWidget(gbox4, 1, 1, 1, 1);
+    m_previewOriginalWidget = previewOriginalWidget();
+    QWhatsThis::add( m_previewOriginalWidget, i18n("<p>You can see here the original image. You can pick "
+                                                   "color on image to select the tone to adjust image's "
+                                                   "white-balance with <b>Color Picker</b> method."));
+    m_previewTargetWidget   = previewTargetWidget();
+    QWhatsThis::add( m_previewTargetWidget, i18n("<p>You can see here the image's white-balance "
+                                                 "adjustments preview. You can pick color on image to "
+                                                 "see the color level corresponding on histogram."));
     
     // -------------------------------------------------------------
     
-    QTimer::singleShot(0, this, SLOT(slotUser1())); // Reset all parameters to the default values.
-    adjustSize();
-    disableResize();
-    parentWidget()->setCursor( KCursor::arrowCursor()  );
+    // Reset all parameters to the default values.
+    QTimer::singleShot(0, this, SLOT(slotDefault()));
 
     // -------------------------------------------------------------
  
     connect(m_channelCB, SIGNAL(activated(int)),
             this, SLOT(slotChannelChanged(int)));
     
-    connect(m_scaleCB, SIGNAL(activated(int)),
+    connect(m_scaleBG, SIGNAL(released(int)),
             this, SLOT(slotScaleChanged(int)));
 
     connect(m_previewOriginalWidget, SIGNAL(spotPositionChanged(  const QColor &, bool, const QPoint & )),
@@ -372,8 +343,12 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
             this, SLOT(slotAutoAdjustExposure()));
 
     connect(m_overExposureIndicatorBox, SIGNAL(toggled (bool)),
-            this, SLOT(slotEffect()));                        
-    
+            this, SLOT(slotEffect()));         
+
+    connect(m_previewTargetWidget, SIGNAL(signalResized()),
+            this, SLOT(slotEffect()));                                        
+
+    // -------------------------------------------------------------                
     // Correction Filter Slider controls.
                         
     connect(m_temperaturePresetCB, SIGNAL(activated(int)),
@@ -402,10 +377,6 @@ ImageEffect_WhiteBalance::ImageEffect_WhiteBalance(QWidget* parent, uint *imageD
 }
 
 ImageEffect_WhiteBalance::~ImageEffect_WhiteBalance()
-{
-}
-
-void ImageEffect_WhiteBalance::closeEvent(QCloseEvent *e)
 {
     m_histogramWidget->stopHistogramComputation();
 
@@ -413,36 +384,6 @@ void ImageEffect_WhiteBalance::closeEvent(QCloseEvent *e)
        delete [] m_destinationPreviewData;
        
     delete m_histogramWidget;
-    e->accept();
-}
-
-void ImageEffect_WhiteBalance::slotUser1()
-{
-    blockSignals(true);
-
-    // Neutral color temperature settings.
-    m_darkInput->setValue(0.5);
-    m_blackInput->setValue(0.0);
-    m_exposureInput->setValue(0.0);
-    m_gammaInput->setValue(1.0);  
-    m_saturationInput->setValue(1.0);  
-    m_greenInput->setValue(1.2);  
-    m_temperaturePresetCB->setCurrentItem(Neutral);
-    slotTemperaturePresetChanged(Neutral);
-    
-    m_previewOriginalWidget->resetSpotPosition();    
-    m_channelCB->setCurrentItem(LuminosityChannel);
-    slotChannelChanged(LuminosityChannel);
-    
-    m_histogramWidget->reset();
-    
-    blockSignals(false);
-    slotEffect();  
-} 
-
-void ImageEffect_WhiteBalance::slotHelp()
-{
-    KApplication::kApplication()->invokeHelp("whitebalance", "digikamimageplugins");
 }
 
 void ImageEffect_WhiteBalance::slotAutoAdjustExposure(void)
@@ -451,7 +392,8 @@ void ImageEffect_WhiteBalance::slotAutoAdjustExposure(void)
 
     // Create an histogram of original image.     
     
-    Digikam::ImageHistogram *histogram = new Digikam::ImageHistogram(m_originalImageData, m_originalWidth, m_originalHeight);
+    Digikam::ImageHistogram *histogram = new Digikam::ImageHistogram(m_originalImageData, 
+                                             m_originalWidth, m_originalHeight);
        
     // Calculate optimal exposition and black level 
     
@@ -643,17 +585,7 @@ void ImageEffect_WhiteBalance::slotColorSelectedFromTarget( const QColor &color
 
 void ImageEffect_WhiteBalance::slotScaleChanged(int scale)
 {
-    switch(scale)
-       {
-       case Linear:
-          m_histogramWidget->m_scaleType = Digikam::HistogramWidget::LinScaleHistogram;
-          break;
-       
-       case Logarithmic:
-          m_histogramWidget->m_scaleType = Digikam::HistogramWidget::LogScaleHistogram;
-          break;
-       }
-
+    m_histogramWidget->m_scaleType = scale;
     m_histogramWidget->repaint(false);
 }
 
@@ -668,17 +600,17 @@ void ImageEffect_WhiteBalance::slotChannelChanged(int channel)
  
        case RedChannel:
           m_histogramWidget->m_channelType = Digikam::HistogramWidget::RedChannelHistogram;
-          m_hGradient->setColors( QColor( "red" ), QColor( "black" ) );
+          m_hGradient->setColors( QColor( "black" ), QColor( "red" ) );
           break;
 
        case GreenChannel:         
           m_histogramWidget->m_channelType = Digikam::HistogramWidget::GreenChannelHistogram;
-          m_hGradient->setColors( QColor( "green" ), QColor( "black" ) );
+          m_hGradient->setColors( QColor( "black" ), QColor( "green" ) );
           break;
 
        case BlueChannel:         
           m_histogramWidget->m_channelType = Digikam::HistogramWidget::BlueChannelHistogram;
-          m_hGradient->setColors( QColor( "blue" ), QColor( "black" ) );
+          m_hGradient->setColors( QColor( "black" ), QColor( "blue" ) );
           break;
        }
 
@@ -687,11 +619,11 @@ void ImageEffect_WhiteBalance::slotChannelChanged(int channel)
 
 void ImageEffect_WhiteBalance::slotEffect()
 {
-    Digikam::ImageIface* iface = m_previewTargetWidget->imageIface();
+    Digikam::ImageIface* ifaceDest = m_previewTargetWidget->imageIface();
 
-    uint*  data   = iface->getPreviewData();
-    int    w      = iface->previewWidth();
-    int    h      = iface->previewHeight();
+    uint*  data   = ifaceDest->getPreviewData();
+    int    w      = ifaceDest->previewWidth();
+    int    h      = ifaceDest->previewHeight();
     
     // Create the new empty destination image data space.
     m_histogramWidget->stopHistogramComputation();
@@ -722,8 +654,8 @@ void ImageEffect_WhiteBalance::slotEffect()
     // Apply White balance adjustments.
     whiteBalance(m_destinationPreviewData, w, h);
            
-    iface->putPreviewData(m_destinationPreviewData);       
-    m_previewTargetWidget->update();
+    ifaceDest->putPreviewData(m_destinationPreviewData);       
+    m_previewTargetWidget->updatePreview();
     
     // Update histogram.
     m_histogramWidget->updateData(m_destinationPreviewData, w, h, 0, 0, 0, false); 
@@ -733,12 +665,12 @@ void ImageEffect_WhiteBalance::slotEffect()
 
 void ImageEffect_WhiteBalance::slotOk()
 {
-    m_parent->setCursor( KCursor::waitCursor() );
-    Digikam::ImageIface iface(0, 0);
+    kapp->setOverrideCursor( KCursor::waitCursor() );
+    Digikam::ImageIface ifaceDest(0, 0);
         
-    uint*  data   = iface.getOriginalData();
-    int    w      = iface.originalWidth();
-    int    h      = iface.originalHeight();
+    uint*  data   = ifaceDest.getOriginalData();
+    int    w      = ifaceDest.originalWidth();
+    int    h      = ifaceDest.originalHeight();
         
     // Update settings
     m_temperature = m_temperatureInput->value()/1000.0;
@@ -761,9 +693,9 @@ void ImageEffect_WhiteBalance::slotOk()
     // Apply White balance adjustments.
     whiteBalance(data, w, h);
 
-    iface.putOriginalData(i18n("White Balance"), data);                   
+    ifaceDest.putOriginalData(i18n("White Balance"), data);                   
     delete [] data;
-    m_parent->setCursor( KCursor::arrowCursor() );
+    kapp->restoreOverrideCursor();
     accept();       
 }
 
@@ -807,72 +739,101 @@ void ImageEffect_WhiteBalance::setLUTv(void)
               << " WP:"   << m_WP
               << endl;
     
-    curve[0] = 0;
+    m_curve[0] = 0;
     
     for (int i = 1; i < 256; i++)
         {
         float x = (float)(i - m_BP)/(m_WP - m_BP);
-        curve[i]  = (i < m_BP) ? 0 : MAXOUT * pow(x, g);
-        curve[i] *= (1 - m_dark * exp(-x * x / 0.002));
-        curve[i] /= (float)i;
+        m_curve[i]  = (i < m_BP) ? 0 : MAXOUT * pow(x, g);
+        m_curve[i] *= (1 - m_dark * exp(-x * x / 0.002));
+        m_curve[i] /= (float)i;
         }
 }
 
 void ImageEffect_WhiteBalance::whiteBalance(uint *data, int width, int height)
 {  
-    int   x, y, c;
-    uint   i;
-
-    uchar *pOutBits = new uchar[width*height*4];
-    uchar *rp = (uchar *)data;
-    uchar *p  = pOutBits;
+    int  x, y;
+    uint i, j=0;
+    Digikam::ImageFilters::imageData imagedata;
          
     for (y = 0 ; y < height ; y++)
         {
-        for (x = 0 ; x < width ; x++, p += 4, rp += 4) 
+        for (x = 0 ; x < width ; x++, j++) 
             {
             int v, rv[3];
-            
-            rv[0] = (int)(rp[0] * m_mb);
-            rv[1] = (int)(rp[1] * m_mg);
-            rv[2] = (int)(rp[2] * m_mr);
+
+            imagedata.raw = data[j];
+            rv[0] = (int)(imagedata.channel.blue  * m_mb);
+            rv[1] = (int)(imagedata.channel.green * m_mg);
+            rv[2] = (int)(imagedata.channel.red   * m_mr);
             v = QMAX(rv[0], rv[1]);
             v = QMAX(v, rv[2]); 
             
-            if (m_clipSat) v = QMIN(v, (int)m_rgbMax);
+            if (m_clipSat) v = QMIN(v, (int)m_rgbMax-1);
             i = v;
 
-            for (c = 0 ; c < 3 ; c++) 
-                {
-                int r, o;
-                
-                r = (m_clipSat && rv[c] > (int)m_rgbMax) ? m_rgbMax : rv[c];
-
-                if (v <= m_BP) 
-                    p[c] = o = 0;
-                else if (m_overExp && v > m_WP) 
-                    {
-                    if (m_WBind)
-                        r = (rv[c] > m_WP) ? 0 : r;
-                    else
-                        r = 0;
-                    }
-                
-                o = (int)((i - m_saturation*(i - r)) * curve[i]);
-                o = QMAX(o, 0);
-                o = (o > MAXOUT) ? 255 : o;
-                
-                p[c] = (uchar)o;
-                }
+            imagedata.channel.blue  = pixelColor(rv[0], i, v);
+            imagedata.channel.green = pixelColor(rv[1], i, v);
+            imagedata.channel.red   = pixelColor(rv[2], i, v);
+            data[j]                 = imagedata.raw;
             }
         }
-
-    memcpy (data, pOutBits, width*height*4);       
-            
-    delete [] pOutBits;    
 }
 
-void ImageEffect_WhiteBalance::slotUser2()
+uchar ImageEffect_WhiteBalance::pixelColor(int colorMult, int index, int value)
+{
+    int r = (m_clipSat && colorMult > (int)m_rgbMax) ? m_rgbMax : colorMult;
+
+    if (value > m_BP && m_overExp && value > m_WP) 
+        {
+        if (m_WBind) 
+           r = (colorMult > m_WP) ? 0 : r;
+        else 
+           r = 0;
+        }
+    
+    return( (uchar)CLAMP((int)((index - m_saturation*(index - r)) * m_curve[index]), 0, MAXOUT) );
+}               
+
+// Reset all settings.
+void ImageEffect_WhiteBalance::slotDefault()
+{
+    m_darkInput->blockSignals(true);
+    m_blackInput->blockSignals(true);
+    m_exposureInput->blockSignals(true);
+    m_gammaInput->blockSignals(true);
+    m_saturationInput->blockSignals(true);  
+    m_greenInput->blockSignals(true);
+    m_temperaturePresetCB->blockSignals(true);
+    
+    // Neutral color temperature settings.
+    m_darkInput->setValue(0.5);
+    m_blackInput->setValue(0.0);
+    m_exposureInput->setValue(0.0);
+    m_gammaInput->setValue(1.0);  
+    m_saturationInput->setValue(1.0);  
+    m_greenInput->setValue(1.2);  
+    m_temperaturePresetCB->setCurrentItem(Neutral);
+    slotTemperaturePresetChanged(Neutral);
+    
+    m_previewOriginalWidget->resetSpotPosition();    
+    m_channelCB->setCurrentItem(LuminosityChannel);
+    slotChannelChanged(LuminosityChannel);
+    
+    m_histogramWidget->reset();
+    
+    m_darkInput->blockSignals(false);
+    m_blackInput->blockSignals(false);
+    m_exposureInput->blockSignals(false);
+    m_gammaInput->blockSignals(false);
+    m_saturationInput->blockSignals(false);  
+    m_greenInput->blockSignals(false);
+    m_temperaturePresetCB->blockSignals(false);
+    slotEffect();  
+} 
+
+// Load all settings.
+void ImageEffect_WhiteBalance::slotUser3()
 {
     KURL loadWhiteBalanceFile = KFileDialog::getOpenURL(KGlobalSettings::documentPath(),
                                              QString( "*" ), this,
@@ -912,7 +873,8 @@ void ImageEffect_WhiteBalance::slotUser2()
     file.close();            
 }
 
-void ImageEffect_WhiteBalance::slotUser3()
+// Save all settings.
+void ImageEffect_WhiteBalance::slotUser2()
 {
     KURL saveWhiteBalanceFile = KFileDialog::getSaveURL(KGlobalSettings::documentPath(),
                                              QString( "*" ), this,
